package com.ynet.life.credit.business;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeAction;
import com.ynet.life.util.PropertiesFile;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Iterator;
import java.util.Properties;
import net.sf.json.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.apache.cxf.jaxrs.client.WebClient;

/* loaded from: com_ynet_life_credit_business.jar:com/ynet/life/credit/business/GetQiXinAction.class */
public class GetQiXinAction extends LifeAction {
    private static String QIXINBAO_COMPONENT = "【【启信宝数据获取接口】】";
    public String corName;
    private String url;
    private String appKey;
    private String secretKey;
    private String profile;
    private static final String ERROR_CODE = "ERQX0001";

    public String execute(Context context) throws GENEException {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cal = Calendar.getInstance();
        context.put("d2_create_time", sdf.format(cal.getTime()));
        String businessName = context.getDataValue(this.corName).toString();
        Properties bankDBSourceProperties = PropertiesFile.getProperties("/properties/qiXinBaoPath.properties");
        this.profile = bankDBSourceProperties.getProperty("profile");
        if (this.profile.equals("master")) {
            this.url = bankDBSourceProperties.getProperty("url");
            this.appKey = bankDBSourceProperties.getProperty("appkey");
            this.secretKey = bankDBSourceProperties.getProperty("secret_key");
        } else {
            this.url = bankDBSourceProperties.getProperty("testUrl");
            this.appKey = bankDBSourceProperties.getProperty("testAppkey");
            this.secretKey = bankDBSourceProperties.getProperty("testSecret_key");
        }
        try {
            String result = getQiXinData(this.url, this.appKey, this.secretKey, businessName, context);
            if (StringUtils.isEmpty(result)) {
                throw new GENEException(ERROR_CODE, "启信宝接口返回结果为空");
            }
            JSONObject jsonOb = JSONObject.fromObject(result);
            if (jsonOb != null) {
                String status = jsonOb.getString("status");
                if ("200".equals(status)) {
                    JSONObject data = JSONObject.fromObject(jsonOb.getString("data"));
                    Iterator<String> itor = data.keys();
                    while (itor.hasNext()) {
                        try {
                            String key = itor.next();
                            String value = data.get(key).toString();
                            context.put(key, value);
                        } catch (Exception unused) {
                        }
                    }
                    return "0";
                }
                GENELog.log(QIXINBAO_COMPONENT, GENELog.INFO, 0, "接口调用失败，状态码：".concat(String.valueOf(status)));
                return "0";
            }
            GENELog.log(QIXINBAO_COMPONENT, GENELog.INFO, 0, "JSON格式错误" + result.toString());
            return "0";
        } catch (Exception e1) {
            throw new GENEException(ERROR_CODE, "启信宝接口调用异常", e1);
        }
    }

    private String getQiXinData(String url, String appKey, String secretKey, String corName, Context context) throws Exception {
        GENELog.log(QIXINBAO_COMPONENT, GENELog.INFO, 0, "入参==url:" + url + " || appKey:" + appKey + " || secretKey:" + secretKey + " || corName:" + corName);
        WebClient client = WebClient.create(url);
        client.accept(new String[]{"application/json"}).type("application/json");
        client.replaceQueryParam("appkey", new Object[]{appKey}).replaceQueryParam("secret_key", new Object[]{secretKey}).replaceQueryParam("name", new Object[]{corName});
        GENELog.log(QIXINBAO_COMPONENT, GENELog.INFO, 0, "请求地址==" + client.getCurrentURI());
        String result = (String) client.get(String.class);
        GENELog.log(QIXINBAO_COMPONENT, GENELog.INFO, 0, "返回结果==" + result.toString());
        context.put("serName", client.getCurrentURI());
        JSONObject jsParam = new JSONObject();
        jsParam.put("appKey", appKey);
        jsParam.put("secretKey", secretKey);
        jsParam.put("corName", corName);
        context.put("accesstoken", jsParam.toString());
        context.put("serResult", result);
        return result;
    }

    public void setCorName(String corName) {
        this.corName = corName;
    }
}
